#
# spec file for package mtail
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%{go_nostrip}
# Project name when using go tooling.
%define project github.com/google/mtail

%bcond_without  apparmor

Name:           mtail
Version:        3.0.0rc51
Release:        5.3
Summary:        Tool for extracting metrics from application logs
License:        Apache-2.0
Group:          System/Management
URL:            https://%{project}
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        %{name}.service
Source3:        %{name}.sysconfig
Source4:        apparmor-usr.sbin.%{name}
Source5:        %{name}.sysuser
BuildRequires:  golang-packaging
BuildRequires:  sysuser-tools
BuildRequires:  golang(API) >= 1.17
Requires(post): %fillup_prereq
Requires(pre):  shadow
%sysusers_requires
%if %{with apparmor}
BuildRequires:  apparmor-abstractions
BuildRequires:  apparmor-rpm-macros
Recommends:     apparmor-abstractions
%endif

%description
mtail is a tool for extracting metrics from application logs to be exported
into a timeseries database or timeseries calculator for alerting and
dashboarding.

%prep
%autosetup -n %{name}-%{version} -a1

%build
%ifarch ppc64
go build -mod=vendor -o mtail cmd/mtail/main.go
%else
go build -mod=vendor -buildmode=pie -o mtail cmd/mtail/main.go
%endif
%sysusers_generate_pre %{SOURCE5} %{name}

%install
# Install the binary
mkdir -p %{buildroot}%{_sbindir}
install -D -m 0755 %{name} "%{buildroot}%{_sbindir}/%{name}"
# Install systemd unit and symbolic link
mkdir -p %{buildroot}%{_unitdir}
install -p -m644 %{SOURCE2} %{buildroot}%{_unitdir}/
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
# Install sysuser configuration
install -D -m 0644 %{SOURCE5} %{buildroot}%{_sysusersdir}/%{name}.conf
# create config directory and create example config files
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
# create sysconfig file
mkdir -p %{buildroot}%{_fillupdir}
install -D -m 0644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.%{name}
%if %{with apparmor}
# AppArmor profile
mkdir -p %{buildroot}%{_sysconfdir}/apparmor.d
install -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/apparmor.d/usr.sbin.%{name}
%endif

%pre -f %{name}.pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%{fillup_only mtail}
%if %{with apparmor}
%apparmor_reload %{_sysconfdir}/apparmor.d/usr.sbin.mtail
%endif

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md
%license LICENSE
%{_sbindir}/%{name}
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_sysusersdir}/%{name}.conf
%dir %attr(0750, root, %{name}) %{_sysconfdir}/%{name}
%if %{with apparmor}
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.sbin.%{name}
%endif
%{_fillupdir}/sysconfig.%{name}

%changelog
* Sat Jun 22 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Adjust system call filter for Leap 15.6
* Mon Feb 26 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Clean up service unit file
* Mon Feb 26 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Support service reload
* Mon Feb 26 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Switch to sysusers
* Mon Dec  4 2023 Georg Pfuetzenreuter <georg.pfuetzenreuter@suse.com>
- Repair system call filter induced startup failure
* Thu Dec 22 2022 michael@stroeder.com
- Update to version 3.0.0rc51:
  * Bump goreleaser/goreleaser-action from 3 to 4
  * Bump github.com/prometheus/common from 0.37.0 to 0.38.0
  * Bump github.com/prometheus/client_golang from 1.13.1 to 1.14.0
  * Bump go.opencensus.io from 0.23.0 to 0.24.0
  * Bump github.com/prometheus/client_golang from 1.13.0 to 1.13.1
  * Bump hmarr/auto-approve-action from 3.0.0 to 3.1.0
  * Bump lewagon/wait-on-check-action from 1.1.2 to 1.2.0
  * Bump hmarr/auto-approve-action from 2.4.0 to 3.0.0
  * Bump actions/stale from 5 to 6
  * Fix linter error
  * Disables rendering dead links
  * Add http_info_endpoint to enable and disable info endpoints
  * Add http_debugging_endpoint flag to allow disabeling http debug endpoint
    (fixes #305)
  * Bump github.com/google/go-cmp from 0.5.8 to 0.5.9
  * Bump hmarr/auto-approve-action from 2.2.1 to 2.4.0
  * Run gofumpt
  * Fix memory leak on corrupt unicode character
  * Bump github.com/prometheus/client_golang from 1.12.2 to 1.13.0
  * ci: Remove actions/cache in favour of setup-go's cache.
  * ci: Use the version of go specified in go.mod
  * Fix missing imports.
  * ci: Fix typo in name of sha-number file on non pull request.
* Wed Aug  3 2022 michael@stroeder.com
- Update to version 3.0.0rc50:
  * ci: Select the correct sha for the test results when running from a post-merge action.
  * Fix typos
  * Fix typo
  * Bump github.com/prometheus/common from 0.36.0 to 0.37.0
  * Bump github.com/prometheus/common from 0.35.0 to 0.36.0
  * Fix golangci-lint code issue
  * Fix store GC not remove all expired metrics
  * Add Non single byte end of read buffer test case
  * Fix golangci-lint issue
  * Fix Unicode replacement character appear in parse result
  * chore: go mod tidy
  * Raise minimum Go version to 1.17.
  * Bump lewagon/wait-on-check-action from 1.1.1 to 1.1.2
  * Bump github.com/prometheus/common from 0.34.0 to 0.35.0
  * Make linter happy
  * Stabelize order of labels in statsd/graphite/collectd export
  * Bump goreleaser/goreleaser-action from 2 to 3
  * Reformat the code to appease the linter.
* Thu May 19 2022 Michael Ströder <michael@stroeder.com>
- Update to version 3.0.0rc49
  * Update the docs for limit.
  * Add a RemoveOldestDatum method to remove the oldest datum from a metric.
  * Store the metric's size limit in the Metric object.
  * Add LIMIT keyword to specify the size limit of a dimensioned metric.
  * Bump github.com/prometheus/client_golang from 1.12.1 to 1.12.2
  * Bump github.com/google/go-cmp from 0.5.7 to 0.5.8
  * Bump github/codeql-action from 1 to 2
  * Bump github.com/prometheus/common from 0.33.0 to 0.34.0
  * Bump actions/setup-go from 2 to 3
  * Bump actions/stale from 4 to 5
  * Bump actions/upload-artifact from 2 to 3
  * Bump codecov/codecov-action from 2.1.0 to 3
  * Bump hmarr/auto-approve-action from 2.2.0 to 2.2.1
  * Bump hmarr/auto-approve-action from 2.1.0 to 2.2.0
  * Bump github.com/prometheus/common from 0.32.1 to 0.33.0
  * Bump actions/cache from 2.1.7 to 3
  * Bump actions/checkout from 2 to 3
  * Bump golangci/golangci-lint-action from 2.5.2 to 3
  * Fix test name in the automerge action.
  * Bump actions/github-script from 5 to 6
  * Run CI on build matrix of all OSes provided.
  * Wait for all checks that start with the name test.
  * support for windows paths
  * Bump github.com/prometheus/client_golang from 1.12.0 to 1.12.1
  * Bump github.com/google/go-cmp from 0.5.6 to 0.5.7
  * Bump github.com/prometheus/client_golang from 1.11.0 to 1.12.0
  * Remove duplicate gosec scan.
  * Rewrite the comment to suit new gosec formatting requirements.
* Mon Nov 22 2021 michael@stroeder.com
- Update to version 3.0.0rc48:
  * Fix small syntax problems in interoperability docs
  * Bump lewagon/wait-on-check-action from 1.0.0 to 1.1.1
  * Make one-shot Prometheus emit prog label and metric timestamp flags
  * Bump codecov/codecov-action from 2.0.3 to 2.1.0
  * Change the flag to -one_shot_format
  * Add -prometheus_output to -one_shot
  * Exit with 0 code when --one_shot is set
  * Bump codecov/codecov-action from 2.0.2 to 2.0.3
  * Bump lewagon/wait-on-check-action from 0.2 to 1.0.0
  * Bump actions/github-script from 4.0.2 to 4.1
  * Comment out permissions in automerge as they're incorrect.
  * examples/apache_metrics.mtail: fix http_request_duration_seconds division
  * Fix permissions for the publish action.
  * Fix a typo.
  * Update last workflows with minimum permissions.
  * Add permissions to more workflows.
  * Make a yaml-valid version of no permissions on the token.
  * Set minimum permissions for benchmarking and uploading benchmark and CI resulrts.
  * Set minimum permissions on auto-review.
  * Remove unnecessary comment.
  * Set minimum required permissions on automerge action.
  * Run security scan on pull requests, not pushes.
  * Bump github.com/prometheus/common from 0.29.0 to 0.30.0
  * Remove uninclusive language.
  * Bump codecov/codecov-action from 2.0.1 to 2.0.2
  * Bump codecov/codecov-action from 1 to 2.0.1
  * doc fix
* Fri Oct  8 2021 Michael Ströder <michael@stroeder.com>
- some more spec-cleanup
* Fri Oct  8 2021 Michael Ströder <michael@stroeder.com>
- use %%go_nostrip macro
* Fri Oct  8 2021 Jan Engelhardt <jengelh@inai.de>
- Trim %%setup repetition
* Mon Sep  6 2021 Michael Ströder <michael@stroeder.com>
- initial packaging of upstream pre-release v3.0.0-rc47
